@@ -79,37 +79,39 @@ def main():
 def parse_options():
     parser = optparse.OptionParser(
         version='Mopidy %s' % versioning.get_version())
+    # NOTE First argument to add_option must be bytestrings on Python < 2.6.2
+    # See https://github.com/mopidy/mopidy/issues/302 for details
     parser.add_option(
-        '--help-gst',
+        b'--help-gst',
         action='store_true', dest='help_gst',
         help='show GStreamer help options')
     parser.add_option(
-        '-i', '--interactive',
+        b'-i', '--interactive',
         action='store_true', dest='interactive',
         help='ask interactively for required settings which are missing')
     parser.add_option(
-        '-q', '--quiet',
+        b'-q', '--quiet',
         action='store_const', const=0, dest='verbosity_level',
         help='less output (warning level)')
     parser.add_option(
-        '-v', '--verbose',
+        b'-v', '--verbose',
         action='count', default=1, dest='verbosity_level',
         help='more output (debug level)')
     parser.add_option(
-        '--save-debug-log',
+        b'--save-debug-log',
         action='store_true', dest='save_debug_log',
         help='save debug log to "./mopidy.log"')
     parser.add_option(
-        '--list-settings',
+        b'--list-settings',
         action='callback',
         callback=settings_utils.list_settings_optparse_callback,
         help='list current settings')
     parser.add_option(
-        '--list-deps',
+        b'--list-deps',
         action='callback', callback=deps.list_deps_optparse_callback,
         help='list dependencies and their versions')
     parser.add_option(
-        '--debug-thread',
+        b'--debug-thread',
         action='store_true', dest='debug_thread',
         help='run background thread that dumps tracebacks on SIGUSR1')
     return parser.parse_args(args=mopidy_args)[0]
