@@ -4,7 +4,7 @@ from mopidy import settings
 from mopidy.backends.local import LocalBackend
 from mopidy.models import Track
 
-from tests import unittest
+from tests import unittest, path_to_data_dir
 from tests.backends.base.tracklist import TracklistControllerTest
 from tests.backends.local import generate_song
 
@@ -16,6 +16,7 @@ class LocalTracklistControllerTest(TracklistControllerTest, unittest.TestCase):
 
     def setUp(self):
         settings.BACKENDS = ('mopidy.backends.local.LocalBackend',)
+        settings.LOCAL_TAG_CACHE_FILE = path_to_data_dir('empty_tag_cache')
         super(LocalTracklistControllerTest, self).setUp()
 
     def tearDown(self):
