@@ -1,6 +1,6 @@
 from __future__ import unicode_literals
 
-from mopidy.models import Album, Artist, Track
+from mopidy.models import Album, Artist, SearchResult, Track
 
 from tests.frontends.mpd import protocol
 
@@ -13,7 +13,61 @@ class MusicDatabaseHandlerTest(protocol.BaseTestCase):
         self.assertInResponse('OK')
 
     def test_findadd(self):
-        self.sendRequest('findadd "album" "what"')
+        self.backend.library.dummy_find_exact_result = SearchResult(
+            tracks=[Track(uri='dummy:a', name='A')])
+        self.assertEqual(self.core.tracklist.length.get(), 0)
+
+        self.sendRequest('findadd "title" "A"')
+
+        self.assertEqual(self.core.tracklist.length.get(), 1)
+        self.assertEqual(self.core.tracklist.tracks.get()[0].uri, 'dummy:a')
+        self.assertInResponse('OK')
+
+    def test_searchadd(self):
+        self.backend.library.dummy_search_result = SearchResult(
+            tracks=[Track(uri='dummy:a', name='A')])
+        self.assertEqual(self.core.tracklist.length.get(), 0)
+
+        self.sendRequest('searchadd "title" "a"')
+
+        self.assertEqual(self.core.tracklist.length.get(), 1)
+        self.assertEqual(self.core.tracklist.tracks.get()[0].uri, 'dummy:a')
+        self.assertInResponse('OK')
+
+    def test_searchaddpl_appends_to_existing_playlist(self):
+        playlist = self.core.playlists.create('my favs').get()
+        playlist = playlist.copy(tracks=[
+            Track(uri='dummy:x', name='X'),
+            Track(uri='dummy:y', name='y'),
+        ])
+        self.core.playlists.save(playlist)
+        self.backend.library.dummy_search_result = SearchResult(
+            tracks=[Track(uri='dummy:a', name='A')])
+        playlists = self.core.playlists.filter(name='my favs').get()
+        self.assertEqual(len(playlists), 1)
+        self.assertEqual(len(playlists[0].tracks), 2)
+
+        self.sendRequest('searchaddpl "my favs" "title" "a"')
+
+        playlists = self.core.playlists.filter(name='my favs').get()
+        self.assertEqual(len(playlists), 1)
+        self.assertEqual(len(playlists[0].tracks), 3)
+        self.assertEqual(playlists[0].tracks[0].uri, 'dummy:x')
+        self.assertEqual(playlists[0].tracks[1].uri, 'dummy:y')
+        self.assertEqual(playlists[0].tracks[2].uri, 'dummy:a')
+        self.assertInResponse('OK')
+
+    def test_searchaddpl_creates_missing_playlist(self):
+        self.backend.library.dummy_search_result = SearchResult(
+            tracks=[Track(uri='dummy:a', name='A')])
+        self.assertEqual(
+            len(self.core.playlists.filter(name='my favs').get()), 0)
+
+        self.sendRequest('searchaddpl "my favs" "title" "a"')
+
+        playlists = self.core.playlists.filter(name='my favs').get()
+        self.assertEqual(len(playlists), 1)
+        self.assertEqual(playlists[0].tracks[0].uri, 'dummy:a')
         self.assertInResponse('OK')
 
     def test_listall(self):
@@ -61,6 +115,66 @@ class MusicDatabaseHandlerTest(protocol.BaseTestCase):
 
 
 class MusicDatabaseFindTest(protocol.BaseTestCase):
+    def test_find_includes_fake_artist_and_album_tracks(self):
+        self.backend.library.dummy_find_exact_result = SearchResult(
+            albums=[Album(uri='dummy:album:a', name='A', date='2001')],
+            artists=[Artist(uri='dummy:artist:b', name='B')],
+            tracks=[Track(uri='dummy:track:c', name='C')])
+
+        self.sendRequest('find "any" "foo"')
+
+        self.assertInResponse('file: dummy:artist:b')
+        self.assertInResponse('Title: Artist: B')
+
+        self.assertInResponse('file: dummy:album:a')
+        self.assertInResponse('Title: Album: A')
+        self.assertInResponse('Date: 2001')
+
+        self.assertInResponse('file: dummy:track:c')
+        self.assertInResponse('Title: C')
+
+        self.assertInResponse('OK')
+
+    def test_find_artist_does_not_include_fake_artist_tracks(self):
+        self.backend.library.dummy_find_exact_result = SearchResult(
+            albums=[Album(uri='dummy:album:a', name='A', date='2001')],
+            artists=[Artist(uri='dummy:artist:b', name='B')],
+            tracks=[Track(uri='dummy:track:c', name='C')])
+
+        self.sendRequest('find "artist" "foo"')
+
+        self.assertNotInResponse('file: dummy:artist:b')
+        self.assertNotInResponse('Title: Artist: B')
+
+        self.assertInResponse('file: dummy:album:a')
+        self.assertInResponse('Title: Album: A')
+        self.assertInResponse('Date: 2001')
+
+        self.assertInResponse('file: dummy:track:c')
+        self.assertInResponse('Title: C')
+
+        self.assertInResponse('OK')
+
+    def test_find_artist_and_album_does_not_include_fake_tracks(self):
+        self.backend.library.dummy_find_exact_result = SearchResult(
+            albums=[Album(uri='dummy:album:a', name='A', date='2001')],
+            artists=[Artist(uri='dummy:artist:b', name='B')],
+            tracks=[Track(uri='dummy:track:c', name='C')])
+
+        self.sendRequest('find "artist" "foo" "album" "bar"')
+
+        self.assertNotInResponse('file: dummy:artist:b')
+        self.assertNotInResponse('Title: Artist: B')
+
+        self.assertNotInResponse('file: dummy:album:a')
+        self.assertNotInResponse('Title: Album: A')
+        self.assertNotInResponse('Date: 2001')
+
+        self.assertInResponse('file: dummy:track:c')
+        self.assertInResponse('Title: C')
+
+        self.assertInResponse('OK')
+
     def test_find_album(self):
         self.sendRequest('find "album" "what"')
         self.assertInResponse('OK')
@@ -127,6 +241,17 @@ class MusicDatabaseFindTest(protocol.BaseTestCase):
 
 
 class MusicDatabaseListTest(protocol.BaseTestCase):
+    def test_list(self):
+        self.backend.library.dummy_find_exact_result = SearchResult(
+            tracks=[
+                Track(uri='dummy:a', name='A', artists=[
+                    Artist(name='A Artist')])])
+
+        self.sendRequest('list "artist" "artist" "foo"')
+
+        self.assertInResponse('Artist: A Artist')
+        self.assertInResponse('OK')
+
     def test_list_foo_returns_ack(self):
         self.sendRequest('list "foo"')
         self.assertEqualResponse('ACK [2@0] {list} incorrect arguments')
@@ -184,8 +309,8 @@ class MusicDatabaseListTest(protocol.BaseTestCase):
         self.assertInResponse('OK')
 
     def test_list_artist_should_not_return_artists_without_names(self):
-        self.backend.library.dummy_find_exact_result = [
-            Track(artists=[Artist(name='')])]
+        self.backend.library.dummy_find_exact_result = SearchResult(
+            tracks=[Track(artists=[Artist(name='')])])
 
         self.sendRequest('list "artist"')
         self.assertNotInResponse('Artist: ')
@@ -243,8 +368,8 @@ class MusicDatabaseListTest(protocol.BaseTestCase):
         self.assertInResponse('OK')
 
     def test_list_album_should_not_return_albums_without_names(self):
-        self.backend.library.dummy_find_exact_result = [
-            Track(album=Album(name=''))]
+        self.backend.library.dummy_find_exact_result = SearchResult(
+            tracks=[Track(album=Album(name=''))])
 
         self.sendRequest('list "album"')
         self.assertNotInResponse('Album: ')
@@ -298,7 +423,8 @@ class MusicDatabaseListTest(protocol.BaseTestCase):
         self.assertInResponse('OK')
 
     def test_list_date_should_not_return_blank_dates(self):
-        self.backend.library.dummy_find_exact_result = [Track(date='')]
+        self.backend.library.dummy_find_exact_result = SearchResult(
+            tracks=[Track(date='')])
 
         self.sendRequest('list "date"')
         self.assertNotInResponse('Date: ')
@@ -354,6 +480,23 @@ class MusicDatabaseListTest(protocol.BaseTestCase):
 
 
 class MusicDatabaseSearchTest(protocol.BaseTestCase):
+    def test_search(self):
+        self.backend.library.dummy_search_result = SearchResult(
+            albums=[Album(uri='dummy:album:a', name='A')],
+            artists=[Artist(uri='dummy:artist:b', name='B')],
+            tracks=[Track(uri='dummy:track:c', name='C')])
+
+        self.sendRequest('search "any" "foo"')
+
+        self.assertInResponse('file: dummy:album:a')
+        self.assertInResponse('Title: Album: A')
+        self.assertInResponse('file: dummy:artist:b')
+        self.assertInResponse('Title: Artist: B')
+        self.assertInResponse('file: dummy:track:c')
+        self.assertInResponse('Title: C')
+
+        self.assertInResponse('OK')
+
     def test_search_album(self):
         self.sendRequest('search "album" "analbum"')
         self.assertInResponse('OK')
